// Initialize empty data structures
let locations = [];
let treasures = [];

// CRUD Functions
function addLocation(name, description) {
  const newLocation = {
    id: Date.now(),
    name,
    description,
    status: 'unexplored',
    treasures: []
  };
  locations.push(newLocation);
  updateUI();
}

function addTreasure(locationId, name, description, value, rarity) {
  const newTreasure = {
    id: Date.now(),
    locationId,
    name,
    description,
    value,
    rarity
  };
  treasures.push(newTreasure);
  updateUI();
}

function updateTreasure(treasureId, newData) {
  const treasure = treasures.find(t => t.id === treasureId);
  if (treasure) {
    Object.assign(treasure, newData);
  }
  updateUI();
}

function deleteLocation(locationId) {
  locations = locations.filter(l => l.id !== locationId);
  treasures = treasures.filter(t => t.locationId !== locationId);
  updateUI();
}

function deleteTreasure(treasureId) {
  treasures = treasures.filter(t => t.id !== treasureId);
  updateUI();
}

// UI Update Function
function updateUI() {
  const locationsContainer = document.querySelector('.feature-grid');
  const treasuresContainer = document.querySelector('.treasure-grid');
  
  // Clear existing content
  locationsContainer.innerHTML = '';
  treasuresContainer.innerHTML = '';
  
  // Render locations
  locations.forEach(location => {
    const locationCard = document.createElement('div');
    locationCard.className = 'feature-card';
    locationCard.innerHTML = `
      <div class="feature-icon">🗺</div>
      <h3>${location.name}</h3>
      <p>${location.description}</p>
      <p>Status: ${location.status}</p>
      <button onclick="editLocation(${location.id})">Edit</button>
      <button onclick="deleteLocation(${location.id})">Delete</button>
    `;
    locationsContainer.appendChild(locationCard);
  });
  
  // Render treasures
  treasures.forEach(treasure => {
    const treasureCard = document.createElement('div');
    treasureCard.className = 'treasure-card';
    treasureCard.innerHTML = `
      <div class="treasure-icon">💎</div>
      <h3>${treasure.name}</h3>
      <p>${treasure.description}</p>
      <p>Value: $${treasure.value}</p>
      <p>Rarity: ${treasure.rarity}</p>
      <button onclick="editTreasure(${treasure.id})">Edit</button>
      <button onclick="deleteTreasure(${treasure.id})">Delete</button>
    `;
    treasuresContainer.appendChild(treasureCard);
  });
}

// Initial Data
addLocation('Amazon Rainforest', 'Lush jungle with ancient artifacts');
addLocation('Himalayan Peaks', 'Frozen relics of lost civilizations');
addLocation('Sahara Desert', 'Buried treasures beneath the sands');

addTreasure(locations[0].id, 'Emerald Amulet', 'Ancient Mayan artifact', 120000, 'Legendary');
addTreasure(locations[1].id, 'Greek Amphora', '4th century BC pottery', 85000, 'Rare');
addTreasure(locations[2].id, 'Easter Island Statue', 'Miniature Moai replica', 45000, 'Uncommon');

// Initialize UI
updateUI();